==> nextcloud-25.0.12p1.tgz: nextcloud/apps/theming/l10n/ar.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "هذا الاسم أطول مما يجب",
    "The given web address is too long" : "هذا العنوان أطول مما يجب",
    "The given web address is not a valid URL" : "عنوان الوب هذا ليس عنوان URL صحيح",
    "The given legal notice address is too long" : "هذه الملاحظة القانونية أطول مما يجب",
    "The given legal notice address is not a valid URL" : "عنوان الملاحظة القانونية هذه ليس عنوان URL صحيح",
    "The given privacy policy address is too long" : "عنوان سياسة الخصوصية هذا أطول مما يجب",
    "The given privacy policy address is not a valid URL" : "عنوان سياسة الخصوصية هذا ليس عنوان URL صحيح",
    "The given slogan is too long" : "هذه الشارة slogan أطول مما يجب",
    "The given color is invalid" : "هذا اللون غير صحيح",
    "Disable-user-theming should be true or false" : "\"إيقاف ثيمة المستخدم\" Disable-user-theming يجب أن تكون إمّا صح أو خطأ",
    "Saved" : "تم الحفظ",
    "The file was uploaded" : "الملف تم رفعه",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "حجم الملف المرفوع قد تجاوز  upload_max_filesize الموجودة في ملف php.ini ",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "حجم الملف الذي تريد ترفيعه أعلى مما MAX_FILE_SIZE يسمح به في واجهة ال HTML.",
    "The file was only partially uploaded" : "الملف قد رُفع جزءا منه فقط",
    "No file was uploaded" : "لم يتم رفع أي ملف",
    "Missing a temporary folder" : "المجلد المؤقت غير موجود",
    "Could not write file to disk" : "لم يستطع كتابة ملف للقرص",
    "A PHP extension stopped the file upload" : "اضافة البي اچ بي PHP اوقفت رفع الملف",
    "No file uploaded" : "لم يتم رفع الملف",
    "Failed to clean up the old administration theming images folder" : "إخفاق في تنظيف مجلد صور ثيمات الإدارة القديمة",
    "Failed to clean up the old administration image folder" : "إخفاق في تنظيف مجلد صور الإدارة القديمة",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "أنت تستخدم الآن ثيمة مُخصّصة. إعدادات تطبيق الثيمات يُمكن أن يتم الكتابة عليها بسبب ذلك. ",
    "Theming" : "تخصيص القالب",
    "Appearance and accessibility" : "المظهر appearance، و سهولة الوصول accessibility",
    "Dark theme with high contrast mode" : "ثيمة داكنة dark مع وضعية تباين عالي",
    "Enable dark high contrast mode" : "فَعِّل وضعية التباين العالي الدّاكن",
    "Similar to the high contrast mode, but with dark colours." : "مُماثلة لوضعية التباين العالي، لكن بألوان داكنة",
    "Dark theme" : "مظهر داكن",
    "Enable dark theme" : "تفعيل المظهر الداكن",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "ثيمة داكنة تريح عينيك من خلال تقليل اللمعان والسطوع بشكل عام",
    "System default theme" : "ثيمة النظام التلقائية",
    "Enable the system default" : "تمكين ثيمة النظام التلقائية",
    "Using the default system appearance." : "إستخدام المظهر التلقائي للنظام",
    "Dyslexia font" : "خط خاص بالمصابين بعسر القراءة",
    "Enable dyslexia font" : "تفعيل الخط الخاص بالمصابين بعسر القراءة",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic خط مجاني مصمم للمساعدة على تفادي الأخطاء لمن يعانون من عسر القراءة.",
    "High contrast mode" : "وضع تباين الألوان العالي",
    "Enable high contrast mode" : "تفعيل وضع تباين الألوان العالي",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "وضع تباين الألوان العالي يساعدك على التنقل في الموقع بسهولة. الجودة المرئية سوف تقل بينما الوضوح سيزداد.",
    "Light theme" : "ثيمة فاتحة light",
    "Enable the default light theme" : "مكّن الثيمة التلقائية الفاتحة",
    "The default light appearance." : "المظهر الفاتح التلقائي",
    "Legal notice" : "ملاحظة قانونية",
    "Privacy policy" : "سياسة الخصوصية",
    "Adjust the Nextcloud theme" : "تضبيط ثيمة نكست كلاود",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "السمات تجعل من الممكن بسهولة تخصيص الشكل والمظهر لنموذجك ودعم العملاء. سيكون هذا مرئيا لجميع المستخدمين.",
    "Advanced options" : "الخيارات المتقدمة",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "قم بتثبيت ImageMagick و التي هي امتداد لـ PHP مع دعم صور SVG لإنشاء الرموز المفضلة تلقائيًا بناءً على الشعار واللون اللذيْن تمّ تحميلهما.",
    "Name" : "الاسم",
    "Web link" : "رابط الويب",
    "a safe home for all your data" : "مكان آمن لكل معلوماتك",
    "Slogan" : "شعار",
    "Color" : "لون",
    "Logo" : "العلامة",
    "Upload new logo" : "رفع شعار جديد",
    "Background and login image" : "صورة الخلفية و تسجيل الدخول",
    "Upload new background and login image" : "إرفع صورة جديدة للخلفية و لتسجيل الدخول",
    "Legal notice link" : "رابط الإشعار القانوني",
    "Privacy policy link" : "رابط سياسة الخصوصية",
    "Header logo" : "شعار الرأسية",
    "Upload new header logo" : "تحميل شعار رأسية جديد",
    "Favicon" : "الأيقونة المفضلة",
    "Upload new favicon" : "تحميل أيقونة مفضلة جديدة",
    "User settings" : "إعدادات المستخدم",
    "Disable user theming" : "إيقاف تصرف المستخدم في الثيمات",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "على الرغم من أنه يمكنك تحديد وتخصيص الخادوم الخاص بك، فإنه يمكن للمستخدمين تغيير صور خلفيات شاشاتهم وألوانهم. إذا كنت تريد فرض التخصيص الخاص بك ، فيمكنك التبديل إلى هذا.",
    "Background" : "خلفية الشاشة",
    "Customization has been disabled by your administrator" : "التخصيص موقوف من قِبَل المُشرف",
    "Set a custom background" : "عيّن خلفيةً مُخصصةً",
    "Keyboard shortcuts" : "إختصارات لوحة المفاتيح",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "في بعض الحالات، يمكن أن تتداخل اختصارات لوحة المفاتيح مع أدوات تسهيل الوصول. للسماح بالتركيز على أداتك بشكل صحيح، يُمكنك تعطيل جميع اختصارات لوحة المفاتيح هنا. سيؤدي هذا أيضًا إلى تعطيل جميع الاختصارات المتاحة في التطبيقات.",
    "Disable all keyboard shortcuts" : "إيقاف كل اختصارات لوحة المفاتيح",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "الوصول الشامل مهم جدا بالنسبة لنا. نحن نتبع معايير ويب صارمة ونتأكد من أن كل شيء يمكن إستعماله حتى دون الحاجة للفأرة أو إلى أي برامج مساعدة مثل برامج قراءة الشاشة. هدفنا أن نكون متوافقين مع {guidelines} توجيهات تسهيل إستعمال محتوى الويب {linkend} 2.1 بمستوى AA، ومتوافقين مع مظهر تباين الألوان العالي بمستوى يصل حتى إلى AAA.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "إذا واجهك أيّ إشكالٍ، فلا تتردد في الإبلاغ عنه على {issuetracker} تطبيقنا لمتابعة الإشكالات {linkend}. وإذا كنت ترغب في المشاركة، فانتقل إلى {designteam} فريق التصميم لدينا {linkend}!",
    "Custom background" : "خلفيّة مُخصّصة",
    "Default background" : "الخلفية التلقائية",
    "Change color" : "غيّر اللون",
    "No background" : "لا خلفية",
    "Select a background from your files" : "إختر خلفية من ملفاتك",
    "Select background" : "إختَر الخلفية",
    "No background has been selected" : "لم يتم اختيار أي خلفية بعد",
    "Theme selection is enforced" : "تمّ فرض اختيار الثيمة",
    "Select a custom color" : "إختر لوناً مُخصّصاً",
    "Reset to default" : "اعادة تعيين الافتراضيات",
    "Upload" : "تحميل",
    "Remove background image" : "إزالة صورة الخلفية",
    "Loading preview…" : "جار تحميل المعاينة ...",
    "Admin" : "ادارة",
    "Error uploading the file" : "خطأ في تحميل الملف",
    "Name cannot be empty" : "لا يمكن أن يكون الاسم فارغاً",
    "Migrate and clean up admin theming images" : "رَحِّل و نَظِّف صور ثيمات المشرف",
    "Failed to clean up the old admin theming images folder" : "تعذّر تنظيف مُجلّد صور ثيمات المشرف القديمة",
    "In some cases keyboard shortcuts can interfer with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "في بعض الحالات، يمكن أن تتداخل اختصارات لوحة المفاتيح مع أدوات تسهيل الوصول. للسماح بالتركيز على أداتك بشكل صحيح، يمكنك تعطيل جميع اختصارات لوحة المفاتيح هنا. سيؤدي هذا أيضًا إلى تعطيل جميع الاختصارات المتاحة في التطبيقات.",
    "Pick from Files" : "اختر من الملفات",
    "Default image" : "الصورة التلقائية",
    "Custom color" : "لون خاص",
    "Plain background" : "خلفية سادة",
    "Insert from {productName}" : "اضف من {productName}",
    "Open documentation" : "فتح الدليل",
    "https://…" : "https://…",
    "Upload new login background" : "تحميل خلفية جديدة للدخول",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can check this box." : "على الرغم من أنه يمكنك تحديد وتخصيص الخادوم الخاص بك، فإنه يمكن للمستخدمين تغيير صور خلفيات شاشاتهم وألوانهم. إذا كنت ترغب في فرض التخصيص الخاص بك، يمكنك تحديد هذا المربع.",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "قم بتثبيت Imagemagick و الذي هو امتداد لـ PHP مع دعم صور SVG لإنشاء الرموز المفضلة تلقائيًا بناءً على الشعار واللون اللذين تم~ تحميلهما."
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> nextcloud-26.0.9.tgz: nextcloud/apps/theming/l10n/ar.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "هذا الاسم أطول مما يجب",
    "The given web address is too long" : "هذا العنوان أطول مما يجب",
    "The given web address is not a valid URL" : "عنوان الوب هذا ليس عنوان URL صحيح",
    "The given legal notice address is too long" : "هذه الملاحظة القانونية أطول مما يجب",
    "The given legal notice address is not a valid URL" : "عنوان الملاحظة القانونية هذه ليس عنوان URL صحيح",
    "The given privacy policy address is too long" : "عنوان سياسة الخصوصية هذا أطول مما يجب",
    "The given privacy policy address is not a valid URL" : "عنوان سياسة الخصوصية هذا ليس عنوان URL صحيح",
    "The given slogan is too long" : "هذه الشارة slogan أطول مما يجب",
    "The given color is invalid" : "هذا اللون غير صحيح",
    "Disable-user-theming should be true or false" : "\"إيقاف ثيمة المستخدم\" Disable-user-theming يجب أن تكون إمّا صح أو خطأ",
    "Saved" : "تم الحفظ",
    "Invalid app given" : "التطبيق المُعطى غير صحيح",
    "Invalid type for setting \"defaultApp\" given" : "النوع المُعطى للإعدادات \"defaultApp\" غير صحيح",
    "Invalid setting key" : "مفتاح الإعدادات غير صحيح",
    "The file was uploaded" : "الملف تم رفعه",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "حجم الملف المرفوع قد تجاوز  upload_max_filesize الموجودة في ملف php.ini ",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "حجم الملف الذي تريد ترفيعه أعلى مما MAX_FILE_SIZE يسمح به في واجهة ال HTML.",
    "The file was only partially uploaded" : "الملف قد رُفع جزءا منه فقط",
    "No file was uploaded" : "لم يتم رفع أي ملف",
    "Missing a temporary folder" : "المجلد المؤقت غير موجود",
    "Could not write file to disk" : "لم يستطع كتابة ملف للقرص",
    "A PHP extension stopped the file upload" : "اضافة البي اچ بي PHP اوقفت رفع الملف",
    "No file uploaded" : "لم يتم رفع الملف",
    "Failed to clean up the old administration theming images folder" : "إخفاق في تنظيف مجلد صور ثيمات الإدارة القديمة",
    "Failed to clean up the old administration image folder" : "إخفاق في تنظيف مجلد صور الإدارة القديمة",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "أنت تستخدم الآن ثيمة مُخصّصة. إعدادات تطبيق الثيمات يُمكن أن يتم الكتابة عليها بسبب ذلك. ",
    "Theming" : "تخصيص القالب",
    "Appearance and accessibility" : "المظهر appearance، و سهولة الوصول accessibility",
    "Dark theme with high contrast mode" : "ثيمة داكنة dark مع وضعية تباين عالي",
    "Enable dark high contrast mode" : "فَعِّل وضعية التباين العالي الدّاكن",
    "Similar to the high contrast mode, but with dark colours." : "مُماثلة لوضعية التباين العالي، لكن بألوان داكنة",
    "Dark theme" : "مظهر داكن",
    "Enable dark theme" : "تفعيل المظهر الداكن",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "ثيمة داكنة تريح عينيك من خلال تقليل اللمعان والسطوع بشكل عام",
    "System default theme" : "ثيمة النظام التلقائية",
    "Enable the system default" : "تمكين ثيمة النظام التلقائية",
    "Using the default system appearance." : "إستخدام المظهر التلقائي للنظام",
    "Dyslexia font" : "خط خاص بالمصابين بعسر القراءة",
    "Enable dyslexia font" : "تفعيل الخط الخاص بالمصابين بعسر القراءة",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic خط مجاني مصمم للمساعدة على تفادي الأخطاء لمن يعانون من عسر القراءة.",
    "High contrast mode" : "وضع تباين الألوان العالي",
    "Enable high contrast mode" : "تفعيل وضع تباين الألوان العالي",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "وضع تباين الألوان العالي يساعدك على التنقل في الموقع بسهولة. الجودة المرئية سوف تقل بينما الوضوح سيزداد.",
    "Light theme" : "ثيمة فاتحة light",
    "Enable the default light theme" : "مكّن الثيمة التلقائية الفاتحة",
    "The default light appearance." : "المظهر الفاتح التلقائي",
    "Legal notice" : "ملاحظة قانونية",
    "Privacy policy" : "سياسة الخصوصية",
    "Adjust the Nextcloud theme" : "تضبيط ثيمة نكست كلاود",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "السمات تجعل من الممكن بسهولة تخصيص الشكل والمظهر لنموذجك ودعم العملاء. سيكون هذا مرئيا لجميع المستخدمين.",
    "Advanced options" : "الخيارات المتقدمة",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "قم بتثبيت ImageMagick و التي هي امتداد لـ PHP مع دعم صور SVG لإنشاء الرموز المفضلة تلقائيًا بناءً على الشعار واللون اللذيْن تمّ تحميلهما.",
    "Name" : "الاسم",
    "Web link" : "رابط الويب",
    "a safe home for all your data" : "مكان آمن لكل معلوماتك",
    "Slogan" : "شعار",
    "Color" : "لون",
    "Logo" : "العلامة",
    "Upload new logo" : "رفع شعار جديد",
    "Background and login image" : "صورة الخلفية و تسجيل الدخول",
    "Upload new background and login image" : "إرفع صورة جديدة للخلفية و لتسجيل الدخول",
    "Legal notice link" : "رابط الإشعار القانوني",
    "Privacy policy link" : "رابط سياسة الخصوصية",
    "Header logo" : "شعار الرأسية",
    "Upload new header logo" : "تحميل شعار رأسية جديد",
    "Favicon" : "الأيقونة المفضلة",
    "Upload new favicon" : "تحميل أيقونة مفضلة جديدة",
    "User settings" : "إعدادات المستخدم",
    "Disable user theming" : "إيقاف تصرف المستخدم في الثيمات",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "على الرغم من أنه يمكنك تحديد وتخصيص الخادوم الخاص بك، فإنه يمكن للمستخدمين تغيير صور خلفيات شاشاتهم وألوانهم. إذا كنت تريد فرض التخصيص الخاص بك ، فيمكنك التبديل إلى هذا.",
    "Background" : "خلفية الشاشة",
    "Customization has been disabled by your administrator" : "التخصيص موقوف من قِبَل المُشرف",
    "Set a custom background" : "عيّن خلفيةً مُخصصةً",
    "Keyboard shortcuts" : "إختصارات لوحة المفاتيح",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "في بعض الحالات، يمكن أن تتداخل اختصارات لوحة المفاتيح مع أدوات تسهيل الوصول. للسماح بالتركيز على أداتك بشكل صحيح، يُمكنك تعطيل جميع اختصارات لوحة المفاتيح هنا. سيؤدي هذا أيضًا إلى تعطيل جميع الاختصارات المتاحة في التطبيقات.",
    "Disable all keyboard shortcuts" : "إيقاف كل اختصارات لوحة المفاتيح",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "الوصول الشامل مهم جدا بالنسبة لنا. نحن نتبع معايير ويب صارمة ونتأكد من أن كل شيء يمكن إستعماله حتى دون الحاجة للفأرة أو إلى أي برامج مساعدة مثل برامج قراءة الشاشة. هدفنا أن نكون متوافقين مع {guidelines} توجيهات تسهيل إستعمال محتوى الويب {linkend} 2.1 بمستوى AA، ومتوافقين مع مظهر تباين الألوان العالي بمستوى يصل حتى إلى AAA.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "إذا واجهك أيّ إشكالٍ، فلا تتردد في الإبلاغ عنه على {issuetracker} تطبيقنا لمتابعة الإشكالات {linkend}. وإذا كنت ترغب في المشاركة، فانتقل إلى {designteam} فريق التصميم لدينا {linkend}!",
    "Current selected app: {app}, position {position} of {total}" : "التطبيق المُحدّد حاليّاً: {app}, الموضع {position} من {total}",
    "Move up" : "نقلٌ للأعلي",
    "Move down" : "نقلٌ للأسفل",
    "Custom background" : "خلفيّة مُخصّصة",
    "Default background" : "الخلفية التلقائية",
    "Change color" : "غيّر اللون",
    "No background" : "لا خلفية",
    "Select a background from your files" : "إختر خلفية من ملفاتك",
    "Select background" : "إختَر الخلفية",
    "No background has been selected" : "لم يتم اختيار أي خلفية بعد",
    "Theme selection is enforced" : "تمّ فرض اختيار الثيمة",
    "Navigation bar settings" : "إعدادات شريط التنقُّل",
    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "يمكنك تهيئة ترتيب التطبيق المستخدم لشريط التنقل. سيكون الإدخال الأول هو التطبيق الافتراضي الذي يتم فتحه بعد تسجيل الدخول أو عند النقر على الشعار.",
    "The default app can not be changed because it was configured by the administrator." : "لا يمكن تغيير التطبيق الافتراضي لأنه تم تكوينه بواسطة المشرف.",
    "The app order was changed, to see it in action you have to reload the page." : "ترتيب التطبيق تمّ تغييره. لرؤية أثر التغيير، يتوجب إعادة تحميل الصفحة.",
    "Reset default app order" : "إعادة التعيين إلى الترتيب التلقائي للتطبيق",
    "Could not set the app order" : "تعذّر تعيين ترتيب التطبيق",
    "Could not reset the app order" : "تعذّرت إعادة تعيين ترتيب التطبيق",
    "Default app" : "التطبيق التلقائي",
    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "التطبيق التلقائي هو التطبيق الذي يتم فتحه بمجرد الدخول أو بمجرد النقر على الشعار في الصفحة الرئيسية.",
    "Use custom default app" : "إستخِدِم تطبيق تلقائي مخصص",
    "Global default app" : "التطبيق التلقائي العام",
    "Global default apps" : "التطبيقات التلقائية العامة",
    "Default app priority" : "أسبقية التطبيق التلقائي",
    "If an app is not enabled for a user, the next app with lower priority is used." : "إذا لم يكن التطبيق مخوَّلاً للمستخدِم، فإن التطبيق التالي في الأسبقية سيقع استعماله.",
    "Could not set global default apps" : "تعذّر تعيين التطبيقات التلقائية العامة",
    "Select a custom color" : "إختر لوناً مُخصّصاً",
    "Reset to default" : "اعادة تعيين الافتراضيات",
    "Upload" : "تحميل",
    "Remove background image" : "إزالة صورة الخلفية",
    "Loading preview…" : "جار تحميل المعاينة ...",
    "Admin" : "ادارة",
    "Error uploading the file" : "خطأ في تحميل الملف",
    "Name cannot be empty" : "لا يمكن أن يكون الاسم فارغاً",
    "Migrate and clean up admin theming images" : "رَحِّل و نَظِّف صور ثيمات المشرف",
    "Failed to clean up the old admin theming images folder" : "تعذّر تنظيف مُجلّد صور ثيمات المشرف القديمة",
    "In some cases keyboard shortcuts can interfer with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "في بعض الحالات، يمكن أن تتداخل اختصارات لوحة المفاتيح مع أدوات تسهيل الوصول. للسماح بالتركيز على أداتك بشكل صحيح، يمكنك تعطيل جميع اختصارات لوحة المفاتيح هنا. سيؤدي هذا أيضًا إلى تعطيل جميع الاختصارات المتاحة في التطبيقات.",
    "Pick from Files" : "اختر من الملفات",
    "Default image" : "الصورة التلقائية",
    "Custom color" : "لون خاص",
    "Plain background" : "خلفية سادة",
    "Insert from {productName}" : "اضف من {productName}",
    "Open documentation" : "فتح الدليل",
    "https://…" : "https://…",
    "Upload new login background" : "تحميل خلفية جديدة للدخول",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can check this box." : "على الرغم من أنه يمكنك تحديد وتخصيص الخادوم الخاص بك، فإنه يمكن للمستخدمين تغيير صور خلفيات شاشاتهم وألوانهم. إذا كنت ترغب في فرض التخصيص الخاص بك، يمكنك تحديد هذا المربع.",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "قم بتثبيت Imagemagick و الذي هو امتداد لـ PHP مع دعم صور SVG لإنشاء الرموز المفضلة تلقائيًا بناءً على الشعار واللون اللذين تم~ تحميلهما."
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
